"use client";

import { useState } from 'react';
import Link from 'next/link';
import { usePathname } from 'next/navigation';

const Sidebar = ({ sidebarOpen, setSidebarOpen }) => {
  const [openMenus, setOpenMenus] = useState({});
  const pathname = usePathname();

  const menuItems = {
    dashboard: [
      {
        label: "Total Agents Property",
        icon: (
          <svg xmlns="http://www.w3.org/2000/svg" className="w-5 h-5 shrink-0" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M17 20h5v-2a3 3 0 00-5.356-1.857M17 20H7m10 0v-2c0-.656-.126-1.283-.356-1.857M7 20H2v-2a3 3 0 015.356-1.857M7 20v-2c0-.656.126-1.283.356-1.857m0 0a5.002 5.002 0 019.288 0M15 7a3 3 0 11-6 0 3 3 0 016 0zm6 3a2 2 0 11-4 0 2 2 0 014 0zM7 10a2 2 0 11-4 0 2 2 0 014 0z" />
          </svg>
        ),
        children: [
          { label: "Approved Property", route: "/admin/agents-property/?view=approved" },
          { label: "Rejected Property", route: "/admin/agents-property/?view=rejected" },
          { label: "Waiting For Approval", route: "/admin/agents-property/?view=waiting" }
        ]
      },
      {
        label: "Landowner Properties",
        icon: (
          <svg xmlns="http://www.w3.org/2000/svg" className="w-5 h-5 shrink-0" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M3 12l2-2m0 0l7-7 7 7M5 10v10a1 1 0 001 1h3m10-11l2 2m-2-2v10a1 1 0 01-1 1h-3m-6 0a1 1 0 001-1v-4a1 1 0 011-1h2a1 1 0 011 1v4a1 1 0 001 1m-6 0h6" />
          </svg>
        ),
        children: [
          { label: "Approved Property", route: "/admin/landownerProject/?view=approved" },
          { label: "Rejected Property", route: "/admin/landownerProject/?view=rejected" },
          { label: "Waiting For Approval", route: "/admin/landownerProject/?view=waiting" }
        ]
      },
      {
        label: "Developer Projects",
        icon: (
          <svg xmlns="http://www.w3.org/2000/svg" className="w-5 h-5 shrink-0" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M19 21V5a2 2 0 00-2-2H7a2 2 0 00-2 2v16m14 0h2m-2 0h-5m-9 0H3m2 0h5M9 7h1m-1 4h1m4-4h1m-1 4h1m-5 10v-5a1 1 0 011-1h2a1 1 0 011 1v5m-4 0h4" />
          </svg>
        ),
        children: [
          { label: "Approved Property", route: "/admin/developerProject/?view=approved" },
          { label: "Rejected Property", route: "/admin/developerProject/?view=rejected" },
          { label: "Waiting For Approval", route: "/admin/developerProject/?view=waiting" }
        ]
      },
      {
        label: "User Enquiry",
        icon: (
          <svg xmlns="http://www.w3.org/2000/svg" className="w-5 h-5 shrink-0" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M8 10h.01M12 10h.01M16 10h.01M9 16H5a2 2 0 01-2-2V6a2 2 0 012-2h14a2 2 0 012 2v8a2 2 0 01-2 2h-5l-5 5v-5z" />
          </svg>
        ),
        children: [
          { label: "Agents Land Enquiry", route: "/admin/publicInquiry/?view=agentInquiry" },
          { label: "Landowner Land Enquiry", route: "/admin/publicInquiry/?view=landownerInquiry" },
          { label: "Developer Land Enquiry", route: "/admin/publicInquiry/?view=developerInquiry" }
        ]
      }
    ],
    others: [
      {
        label: "Blog",
        icon: (
          <svg xmlns="http://www.w3.org/2000/svg" className="w-5 h-5 shrink-0" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M19 20H5a2 2 0 01-2-2V6a2 2 0 012-2h10a2 2 0 012 2v1m2 13a2 2 0 01-2-2V7m2 13a2 2 0 002-2V9.5a2.5 2.5 0 00-2.5-2.5H15M9 11l3 3m0 0l3-3m-3 3V8" />
          </svg>
        ),
        children: [
          { label: "Create Blog Category", route: "/admin/blog/category" },
          { label: "Create Blog", route: "/admin/blog/create" }
        ]
      },
      {
        label: "Package",
        icon: (
          <svg xmlns="http://www.w3.org/2000/svg" className="w-5 h-5 shrink-0" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M20 7l-8-4-8 4m16 0l-8 4m8-4v10l-8 4m0-10L4 7m8 4v10M4 7v10l8 4" />
          </svg>
        ),
        children: [
          { label: "Create Package", route: "/admin/package/create" },
          { label: "Delete", route: "/admin/package/delete" }
        ]
      },
      {
        label: "Contact US",
        icon: (
          <svg xmlns="http://www.w3.org/2000/svg" className="w-5 h-5 shrink-0" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M3 8l7.89 5.26a2 2 0 002.22 0L21 8M5 19h14a2 2 0 002-2V7a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z" />
          </svg>
        ),
        route: "/admin/contact"
      },
      {
        label: "Payment Request",
        icon: (
          <svg xmlns="http://www.w3.org/2000/svg" className="w-5 h-5 shrink-0" viewBox="0 0 24 24" fill="none" stroke="currentColor">
            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M17 9V7a2 2 0 00-2-2H5a2 2 0 00-2 2v6a2 2 0 002 2h2m2 4h10a2 2 0 002-2v-6a2 2 0 00-2-2H9a2 2 0 00-2 2v6a2 2 0 002 2zm7-5a2 2 0 11-4 0 2 2 0 014 0z" />
          </svg>
        ),
        route: "/admin/payment-requests"
      }
    ]
  };

  const toggleMenu = (menuId) => {
    setOpenMenus(prev => ({
      ...prev,
      [menuId]: !prev[menuId]
    }));
  };

  const MenuItem = ({ item, index, section }) => {
    const menuId = `${section}-${index}`;
    const isOpen = openMenus[menuId];

    if (item.children) {
      return (
        <div className="mb-1">
          <div className="flex items-center w-full">
            <div
              className="flex-1 flex items-center px-2 py-2 rounded-lg hover:bg-gray-700 transition-colors group cursor-pointer"
              onClick={() => toggleMenu(menuId)}
            >
              {item.icon}
              <span className="text-sm font-medium ml-2">{item.label}</span>
              <svg
                xmlns="http://www.w3.org/2000/svg"
                className={`w-4 h-4 ml-auto transition-transform duration-200 ${isOpen ? 'rotate-180' : ''}`}
                viewBox="0 0 24 24"
                fill="none"
                stroke="currentColor"
              >
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M19 9l-7 7-7-7" />
              </svg>
            </div>
          </div>
          
          {isOpen && (
            <div className="mt-1 ml-6 space-y-1">
              {item.children.map((child, childIndex) => (
                <Link
                  key={childIndex}
                  href={child.route}
                  className="block px-2 py-1.5 text-sm text-gray-400 rounded-lg hover:bg-gray-700 hover:text-white transition-colors"
                  onClick={() => sidebarOpen && setSidebarOpen(false)}
                >
                  {child.label}
                </Link>
              ))}
            </div>
          )}
        </div>
      );
    }

    return (
      <Link
        href={item.route}
        className="flex items-center space-x-2 px-2 py-2 rounded-lg hover:bg-gray-700 transition-colors group"
        onClick={() => sidebarOpen && setSidebarOpen(false)}
      >
        {item.icon}
        <span className="text-sm font-medium">{item.label}</span>
      </Link>
    );
  };

  return (
    <>
      {sidebarOpen && (
        <div 
          className="fixed inset-0 bg-black bg-opacity-50 lg:hidden z-40"
          onClick={() => setSidebarOpen(false)}
        />
      )}

      <aside
        className={`
          fixed top-0 left-0 w-72 h-screen bg-[#1C2434] text-gray-300 
          transition-transform duration-300 ease-in-out lg:translate-x-0
          ${sidebarOpen ? 'translate-x-0 z-50' : '-translate-x-full z-30'}
        `}
      >
        <div className="flex flex-col h-full">
          <div className="flex items-center justify-between p-4 border-b border-gray-700">
            <Link href="/admin/admin_dash" className="flex items-center space-x-2">
              <div className="w-8 h-8 bg-purple-600 rounded-lg flex items-center justify-center">
                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" className="w-5 h-5">
                  <path d="M2 8.5L12 2l10 6.5m-10 6L2 8.5m10 6l10-6.5M2 15.5L12 22l10-6.5m-10-6v6"></path>
                </svg>
              </div>
              <span className="text-xl font-semibold text-white">Jaminjaidad</span>
            </Link>

            <button
              onClick={() => setSidebarOpen(false)}
              className="p-1 rounded-lg hover:bg-gray-700 lg:hidden"
            >
              <svg
                className="w-6 h-6"
                fill="none"
                stroke="currentColor"
                viewBox="0 0 24 24"
              >
                <path
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  strokeWidth={2}
                  d="M6 18L18 6M6 6l12 12"
                />
              </svg>
            </button>
          </div>

          <div className="flex-1 overflow-y-auto">
            <div className="p-4">
              <p className="text-xs font-semibold text-gray-400 uppercase mb-4">
                DASHBOARD
              </p>
              <nav className="space-y-1">
                {menuItems.dashboard.map((item, index) => (
                  <MenuItem key={index} item={item} index={index} section="dashboard" />
                ))}
              </nav>

              <p className="text-xs font-semibold text-gray-400 uppercase mt-8 mb-4">
                OTHERS
              </p>
              <nav className="space-y-1">
                {menuItems.others.map((item, index) => (
                  <MenuItem key={index} item={item} index={index} section="others" />
                ))}
              </nav>
            </div>
          </div>
        </div>
      </aside>
    </>
  );
};

export default Sidebar;